SumDiffFrequencySpace
=====================

.. currentmodule:: spdcalc.spdcalc

.. autoclass:: SumDiffFrequencySpace
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~SumDiffFrequencySpace.from_frequency_space
      ~SumDiffFrequencySpace.from_wavelength_space
      ~SumDiffFrequencySpace.set_resolution
      ~SumDiffFrequencySpace.to_frequency_space
      ~SumDiffFrequencySpace.to_wavelength_space

   .. rubric:: Methods Documentation

   .. automethod:: from_frequency_space
   .. automethod:: from_wavelength_space
   .. automethod:: set_resolution
   .. automethod:: to_frequency_space
   .. automethod:: to_wavelength_space
